---
title: Docs
type: docs
weight: 1
prev: docs/developer-guide
next: docs/get-started
---

`PETsARD` (Privacy Enhancing Technologies Analysis, Research, and Development, /pəˈtɑrd/) is a Python library for facilitating data generation algorithm and their evaluation processes.

The main functionalities include dataset description, various dataset generation algorithms, and the measurements on privacy protection and utility.

## Design Structure

The following outlines the design of the experiment workflow and the package structure of `PETsARD`:

<p align="center"><img src="/petsard/images/PETsARD_design_en.png"></p>

## Release History

- [Milestone](https://github.com/nics-tw/PETsARD/releases/latest)
  - The Milestone document provide detailed information about the latest version of `PETsARD`.
- [Release Note](https://github.com/nics-tw/petsard/releases)
  - Release note provides information of each version of `PETsARD`.
- [CHANGELOG.md](https://github.com/nics-tw/petsard/blob/main/CHANGELOG.md)
  - Changelog provides evolution of the `PETsARD` over time.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change. And please make sure to update tests as appropriate.